==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GmsaAuthenticationPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GmsaAuthenticationPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Class for GMSA authentication details to configure Active Directory connectivity.
 * @property adDomainControllerDns Gets or sets the list of dns server that can resolve the Active Directory Domain Name/Address.
 * @property adDomainFqdn Gets or sets the FQDN of the Active Directory Domain. For e.g. 'contoso.local', 'fareast.corp.microsoft.com' etc.
 * @property akvProperties
 * @property domainAdminPassword Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.DomainAdminUsername.
 * @property domainAdminUsername Gets or sets the name of the user having admin rights on the Active Directory Domain Controller.
 * @property domainControllerAddress Gets or sets the address of the Active Directory Domain Controller running Domain Services.
 * @property gmsaAccountName Gets or sets the name to be used for GMSA.
 * @property gmsaUserPassword Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.GmsaUsername.
 * @property gmsaUsername Gets or sets username of the user having authorization to access GMSA on Active Directory.
 */
public data class GmsaAuthenticationPropertiesArgs(
    public val adDomainControllerDns: Output<String>? = null,
    public val adDomainFqdn: Output<String>? = null,
    public val akvProperties: Output<KeyVaultSecretStorePropertiesArgs>? = null,
    public val domainAdminPassword: Output<String>? = null,
    public val domainAdminUsername: Output<String>? = null,
    public val domainControllerAddress: Output<String>? = null,
    public val gmsaAccountName: Output<String>? = null,
    public val gmsaUserPassword: Output<String>? = null,
    public val gmsaUsername: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GmsaAuthenticationPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.GmsaAuthenticationPropertiesArgs =
        com.pulumi.azurenative.migrate.inputs.GmsaAuthenticationPropertiesArgs.builder()
            .adDomainControllerDns(adDomainControllerDns?.applyValue({ args0 -> args0 }))
            .adDomainFqdn(adDomainFqdn?.applyValue({ args0 -> args0 }))
            .akvProperties(akvProperties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .domainAdminPassword(domainAdminPassword?.applyValue({ args0 -> args0 }))
            .domainAdminUsername(domainAdminUsername?.applyValue({ args0 -> args0 }))
            .domainControllerAddress(domainControllerAddress?.applyValue({ args0 -> args0 }))
            .gmsaAccountName(gmsaAccountName?.applyValue({ args0 -> args0 }))
            .gmsaUserPassword(gmsaUserPassword?.applyValue({ args0 -> args0 }))
            .gmsaUsername(gmsaUsername?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GmsaAuthenticationPropertiesArgs].
 */
@PulumiTagMarker
public class GmsaAuthenticationPropertiesArgsBuilder internal constructor() {
    private var adDomainControllerDns: Output<String>? = null

    private var adDomainFqdn: Output<String>? = null

    private var akvProperties: Output<KeyVaultSecretStorePropertiesArgs>? = null

    private var domainAdminPassword: Output<String>? = null

    private var domainAdminUsername: Output<String>? = null

    private var domainControllerAddress: Output<String>? = null

    private var gmsaAccountName: Output<String>? = null

    private var gmsaUserPassword: Output<String>? = null

    private var gmsaUsername: Output<String>? = null

    /**
     * @param value Gets or sets the list of dns server that can resolve the Active Directory Domain Name/Address.
     */
    @JvmName("gbkmwolihrgtwnrn")
    public suspend fun adDomainControllerDns(`value`: Output<String>) {
        this.adDomainControllerDns = value
    }

    /**
     * @param value Gets or sets the FQDN of the Active Directory Domain. For e.g. 'contoso.local', 'fareast.corp.microsoft.com' etc.
     */
    @JvmName("mlipytxohcimxdcv")
    public suspend fun adDomainFqdn(`value`: Output<String>) {
        this.adDomainFqdn = value
    }

    /**
     * @param value
     */
    @JvmName("mnltasynkbulfedh")
    public suspend fun akvProperties(`value`: Output<KeyVaultSecretStorePropertiesArgs>) {
        this.akvProperties = value
    }

    /**
     * @param value Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.DomainAdminUsername.
     */
    @JvmName("xahsiajjxatjhcis")
    public suspend fun domainAdminPassword(`value`: Output<String>) {
        this.domainAdminPassword = value
    }

    /**
     * @param value Gets or sets the name of the user having admin rights on the Active Directory Domain Controller.
     */
    @JvmName("cuuxkwthgqtnqguq")
    public suspend fun domainAdminUsername(`value`: Output<String>) {
        this.domainAdminUsername = value
    }

    /**
     * @param value Gets or sets the address of the Active Directory Domain Controller running Domain Services.
     */
    @JvmName("wmdrtjwqppbpklym")
    public suspend fun domainControllerAddress(`value`: Output<String>) {
        this.domainControllerAddress = value
    }

    /**
     * @param value Gets or sets the name to be used for GMSA.
     */
    @JvmName("iopepmgjbhsgjrdg")
    public suspend fun gmsaAccountName(`value`: Output<String>) {
        this.gmsaAccountName = value
    }

    /**
     * @param value Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.GmsaUsername.
     */
    @JvmName("aiurigeomcwdhmvg")
    public suspend fun gmsaUserPassword(`value`: Output<String>) {
        this.gmsaUserPassword = value
    }

    /**
     * @param value Gets or sets username of the user having authorization to access GMSA on Active Directory.
     */
    @JvmName("yfhrtbvghftcdwgm")
    public suspend fun gmsaUsername(`value`: Output<String>) {
        this.gmsaUsername = value
    }

    /**
     * @param value Gets or sets the list of dns server that can resolve the Active Directory Domain Name/Address.
     */
    @JvmName("ikupuvubomxohllc")
    public suspend fun adDomainControllerDns(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.adDomainControllerDns = mapped
    }

    /**
     * @param value Gets or sets the FQDN of the Active Directory Domain. For e.g. 'contoso.local', 'fareast.corp.microsoft.com' etc.
     */
    @JvmName("eexoilfrmtsacpbp")
    public suspend fun adDomainFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.adDomainFqdn = mapped
    }

    /**
     * @param value
     */
    @JvmName("xafkyfuxxgqhadac")
    public suspend fun akvProperties(`value`: KeyVaultSecretStorePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.akvProperties = mapped
    }

    /**
     * @param argument
     */
    @JvmName("whwsckgylnfqrgbv")
    public suspend
    fun akvProperties(argument: suspend KeyVaultSecretStorePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = KeyVaultSecretStorePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.akvProperties = mapped
    }

    /**
     * @param value Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.DomainAdminUsername.
     */
    @JvmName("sdpqrygylqoqqhug")
    public suspend fun domainAdminPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainAdminPassword = mapped
    }

    /**
     * @param value Gets or sets the name of the user having admin rights on the Active Directory Domain Controller.
     */
    @JvmName("shwipbdkqvrafklg")
    public suspend fun domainAdminUsername(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainAdminUsername = mapped
    }

    /**
     * @param value Gets or sets the address of the Active Directory Domain Controller running Domain Services.
     */
    @JvmName("pwqctjlvunhgktcn")
    public suspend fun domainControllerAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainControllerAddress = mapped
    }

    /**
     * @param value Gets or sets the name to be used for GMSA.
     */
    @JvmName("xyjxdqbpvhikgbmu")
    public suspend fun gmsaAccountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gmsaAccountName = mapped
    }

    /**
     * @param value Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.GmsaUsername.
     */
    @JvmName("dpsjoowsgpyrooqe")
    public suspend fun gmsaUserPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gmsaUserPassword = mapped
    }

    /**
     * @param value Gets or sets username of the user having authorization to access GMSA on Active Directory.
     */
    @JvmName("fbdieellslwvwvao")
    public suspend fun gmsaUsername(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gmsaUsername = mapped
    }

    internal fun build(): GmsaAuthenticationPropertiesArgs = GmsaAuthenticationPropertiesArgs(
        adDomainControllerDns = adDomainControllerDns,
        adDomainFqdn = adDomainFqdn,
        akvProperties = akvProperties,
        domainAdminPassword = domainAdminPassword,
        domainAdminUsername = domainAdminUsername,
        domainControllerAddress = domainControllerAddress,
        gmsaAccountName = gmsaAccountName,
        gmsaUserPassword = gmsaUserPassword,
        gmsaUsername = gmsaUsername,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/GmsaAuthenticationPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.GmsaAuthenticationPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Class for GMSA authentication details to configure Active Directory connectivity.
 * @property adDomainControllerDns Gets or sets the list of dns server that can resolve the Active Directory Domain Name/Address.
 * @property adDomainFqdn Gets or sets the FQDN of the Active Directory Domain. For e.g. 'contoso.local', 'fareast.corp.microsoft.com' etc.
 * @property akvProperties
 * @property domainAdminPassword Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.DomainAdminUsername.
 * @property domainAdminUsername Gets or sets the name of the user having admin rights on the Active Directory Domain Controller.
 * @property domainControllerAddress Gets or sets the address of the Active Directory Domain Controller running Domain Services.
 * @property gmsaAccountName Gets or sets the name to be used for GMSA.
 * @property gmsaUserPassword Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.GmsaUsername.
 * @property gmsaUsername Gets or sets username of the user having authorization to access GMSA on Active Directory.
 */
public data class GmsaAuthenticationPropertiesArgs(
    public val adDomainControllerDns: Output<String>? = null,
    public val adDomainFqdn: Output<String>? = null,
    public val akvProperties: Output<KeyVaultSecretStorePropertiesArgs>? = null,
    public val domainAdminPassword: Output<String>? = null,
    public val domainAdminUsername: Output<String>? = null,
    public val domainControllerAddress: Output<String>? = null,
    public val gmsaAccountName: Output<String>? = null,
    public val gmsaUserPassword: Output<String>? = null,
    public val gmsaUsername: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.GmsaAuthenticationPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.GmsaAuthenticationPropertiesArgs =
        com.pulumi.azurenative.migrate.inputs.GmsaAuthenticationPropertiesArgs.builder()
            .adDomainControllerDns(adDomainControllerDns?.applyValue({ args0 -> args0 }))
            .adDomainFqdn(adDomainFqdn?.applyValue({ args0 -> args0 }))
            .akvProperties(akvProperties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .domainAdminPassword(domainAdminPassword?.applyValue({ args0 -> args0 }))
            .domainAdminUsername(domainAdminUsername?.applyValue({ args0 -> args0 }))
            .domainControllerAddress(domainControllerAddress?.applyValue({ args0 -> args0 }))
            .gmsaAccountName(gmsaAccountName?.applyValue({ args0 -> args0 }))
            .gmsaUserPassword(gmsaUserPassword?.applyValue({ args0 -> args0 }))
            .gmsaUsername(gmsaUsername?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GmsaAuthenticationPropertiesArgs].
 */
@PulumiTagMarker
public class GmsaAuthenticationPropertiesArgsBuilder internal constructor() {
    private var adDomainControllerDns: Output<String>? = null

    private var adDomainFqdn: Output<String>? = null

    private var akvProperties: Output<KeyVaultSecretStorePropertiesArgs>? = null

    private var domainAdminPassword: Output<String>? = null

    private var domainAdminUsername: Output<String>? = null

    private var domainControllerAddress: Output<String>? = null

    private var gmsaAccountName: Output<String>? = null

    private var gmsaUserPassword: Output<String>? = null

    private var gmsaUsername: Output<String>? = null

    /**
     * @param value Gets or sets the list of dns server that can resolve the Active Directory Domain Name/Address.
     */
    @JvmName("roxxamynnmqvptyf")
    public suspend fun adDomainControllerDns(`value`: Output<String>) {
        this.adDomainControllerDns = value
    }

    /**
     * @param value Gets or sets the FQDN of the Active Directory Domain. For e.g. 'contoso.local', 'fareast.corp.microsoft.com' etc.
     */
    @JvmName("mrrelxdbhrmafnaj")
    public suspend fun adDomainFqdn(`value`: Output<String>) {
        this.adDomainFqdn = value
    }

    /**
     * @param value
     */
    @JvmName("uepmfoeauukhmfvr")
    public suspend fun akvProperties(`value`: Output<KeyVaultSecretStorePropertiesArgs>) {
        this.akvProperties = value
    }

    /**
     * @param value Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.DomainAdminUsername.
     */
    @JvmName("qmbaoviclfpkqbro")
    public suspend fun domainAdminPassword(`value`: Output<String>) {
        this.domainAdminPassword = value
    }

    /**
     * @param value Gets or sets the name of the user having admin rights on the Active Directory Domain Controller.
     */
    @JvmName("bkhmtwtxmypgihso")
    public suspend fun domainAdminUsername(`value`: Output<String>) {
        this.domainAdminUsername = value
    }

    /**
     * @param value Gets or sets the address of the Active Directory Domain Controller running Domain Services.
     */
    @JvmName("ywvudpqdbkffvtry")
    public suspend fun domainControllerAddress(`value`: Output<String>) {
        this.domainControllerAddress = value
    }

    /**
     * @param value Gets or sets the name to be used for GMSA.
     */
    @JvmName("fgtsksognfutsooa")
    public suspend fun gmsaAccountName(`value`: Output<String>) {
        this.gmsaAccountName = value
    }

    /**
     * @param value Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.GmsaUsername.
     */
    @JvmName("tagavoufoujoqbet")
    public suspend fun gmsaUserPassword(`value`: Output<String>) {
        this.gmsaUserPassword = value
    }

    /**
     * @param value Gets or sets username of the user having authorization to access GMSA on Active Directory.
     */
    @JvmName("ltvqrkidoeuhxxps")
    public suspend fun gmsaUsername(`value`: Output<String>) {
        this.gmsaUsername = value
    }

    /**
     * @param value Gets or sets the list of dns server that can resolve the Active Directory Domain Name/Address.
     */
    @JvmName("hnsysnlpujyiehet")
    public suspend fun adDomainControllerDns(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.adDomainControllerDns = mapped
    }

    /**
     * @param value Gets or sets the FQDN of the Active Directory Domain. For e.g. 'contoso.local', 'fareast.corp.microsoft.com' etc.
     */
    @JvmName("tgwisbaukiblwpmk")
    public suspend fun adDomainFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.adDomainFqdn = mapped
    }

    /**
     * @param value
     */
    @JvmName("lwlgxdpcxmieeteb")
    public suspend fun akvProperties(`value`: KeyVaultSecretStorePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.akvProperties = mapped
    }

    /**
     * @param argument
     */
    @JvmName("kiqdmqaoaicqedfr")
    public suspend
    fun akvProperties(argument: suspend KeyVaultSecretStorePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = KeyVaultSecretStorePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.akvProperties = mapped
    }

    /**
     * @param value Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.DomainAdminUsername.
     */
    @JvmName("drtrtxsrngwvdmgw")
    public suspend fun domainAdminPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainAdminPassword = mapped
    }

    /**
     * @param value Gets or sets the name of the user having admin rights on the Active Directory Domain Controller.
     */
    @JvmName("iyauovenltaeocny")
    public suspend fun domainAdminUsername(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainAdminUsername = mapped
    }

    /**
     * @param value Gets or sets the address of the Active Directory Domain Controller running Domain Services.
     */
    @JvmName("lobuecsbpwlldbyl")
    public suspend fun domainControllerAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.domainControllerAddress = mapped
    }

    /**
     * @param value Gets or sets the name to be used for GMSA.
     */
    @JvmName("kggisnkfcsdhlllw")
    public suspend fun gmsaAccountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gmsaAccountName = mapped
    }

    /**
     * @param value Gets or sets the password of the user specified by RestApi.Controllers.V2022_05_01_preview.Models.WorkloadDeployment.Gmsa.GmsaAuthenticationProperties.GmsaUsername.
     */
    @JvmName("alpubtemkbqvunyp")
    public suspend fun gmsaUserPassword(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gmsaUserPassword = mapped
    }

    /**
     * @param value Gets or sets username of the user having authorization to access GMSA on Active Directory.
     */
    @JvmName("juaalbfjfagdlvrw")
    public suspend fun gmsaUsername(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gmsaUsername = mapped
    }

    internal fun build(): GmsaAuthenticationPropertiesArgs = GmsaAuthenticationPropertiesArgs(
        adDomainControllerDns = adDomainControllerDns,
        adDomainFqdn = adDomainFqdn,
        akvProperties = akvProperties,
        domainAdminPassword = domainAdminPassword,
        domainAdminUsername = domainAdminUsername,
        domainControllerAddress = domainControllerAddress,
        gmsaAccountName = gmsaAccountName,
        gmsaUserPassword = gmsaUserPassword,
        gmsaUsername = gmsaUsername,
    )
}
